@@ -1,4 +1,5 @@
 """Number tests."""
+
 from __future__ import annotations
 
 import math
@@ -118,14 +119,21 @@ def test_intword_powers() -> None:
         ([1_000_000_000_000_000_000_000_000_000_000_000_000], "1000.0 decillion"),
         ([1_100_000_000_000_000_000_000_000_000_000_000_000], "1100.0 decillion"),
         ([2_100_000_000_000_000_000_000_000_000_000_000_000], "2100.0 decillion"),
+        ([2e100], "2.0 googol"),
         ([None], "None"),
         (["1230000", "%0.2f"], "1.23 million"),
-        ([10**101], "1" + "0" * 101),
+        ([10**101], "10.0 googol"),
         ([math.nan], "NaN"),
         ([math.inf], "+Inf"),
         ([-math.inf], "-Inf"),
         (["nan"], "NaN"),
         (["-inf"], "-Inf"),
+        (["1234567", "%.0f"], "1 million"),
+        (["1234567", "%.1f"], "1.2 million"),
+        (["1234567", "%.2f"], "1.23 million"),
+        (["1234567", "%.3f"], "1.235 million"),
+        (["999500", "%.0f"], "1 million"),
+        (["999499", "%.0f"], "999 thousand"),
     ],
 )
 def test_intword(test_args: list[str], expected: str) -> None:
@@ -190,17 +198,17 @@ def test_fractional(test_input: float | str, expected: str) -> None:
         ([5781651000], "5.78 x 10⁹"),
         (["1000"], "1.00 x 10³"),
         (["99"], "9.90 x 10¹"),
-        ([float(0.3)], "3.00 x 10⁻¹"),
+        ([0.3], "3.00 x 10⁻¹"),
         (["foo"], "foo"),
         ([None], "None"),
         ([1000, 1], "1.0 x 10³"),
-        ([float(0.3), 1], "3.0 x 10⁻¹"),
+        ([0.3, 1], "3.0 x 10⁻¹"),
         ([1000, 0], "1 x 10³"),
-        ([float(0.3), 0], "3 x 10⁻¹"),
-        ([float(1e20)], "1.00 x 10²⁰"),
-        ([float(2e-20)], "2.00 x 10⁻²⁰"),
-        ([float(-3e20)], "-3.00 x 10²⁰"),
-        ([float(-4e-20)], "-4.00 x 10⁻²⁰"),
+        ([0.3, 0], "3 x 10⁻¹"),
+        ([1e20], "1.00 x 10²⁰"),
+        ([2e-20], "2.00 x 10⁻²⁰"),
+        ([-3e20], "-3.00 x 10²⁰"),
+        ([-4e-20], "-4.00 x 10⁻²⁰"),
         ([math.nan], "NaN"),
         ([math.inf], "+Inf"),
         ([-math.inf], "-Inf"),
@@ -269,6 +277,27 @@ def test_clamp(test_args: list[typing.Any], expected: str) -> None:
         ([0.1, "°"], "100m°"),
         ([100], "100"),
         ([0.1], "100 m"),
+        ([1.5123, "", 0], "2"),
+        ([10.5123, "", 0], "11"),
+        ([10.5123, "", 1], "11"),
+        ([10.5123, "", 2], "11"),
+        ([10.5123, "", 3], "10.5"),
+        ([1, "", 0], "1"),
+        ([10, "", 0], "10"),
+        ([100, "", 0], "100"),
+        ([1000, "", 0], "1 k"),
+        ([1, "", 1], "1"),
+        ([10, "", 1], "10"),
+        ([100, "", 1], "100"),
+        ([1000, "", 1], "1 k"),
+        ([1, "", 2], "1.0"),
+        ([10, "", 2], "10"),
+        ([100, "", 2], "100"),
+        ([1000, "", 2], "1.0 k"),
+        ([1, "", 3], "1.00"),
+        ([10, "", 3], "10.0"),
+        ([100, "", 3], "100"),
+        ([1000, "", 3], "1.00 k"),
         ([math.nan], "NaN"),
         ([math.nan, "m"], "NaN"),
         ([math.inf], "+Inf"),
